@@ -1,4 +1,4 @@
-from .lpStateVar import LPStateVar
+from .lpStateVar import LPStateVar,LPStateVar_add,LPStateVar_Decision_add
 class Equation:
     '''Simple class for new equations. The Format is alway: Sum(stateVar*factor) >sense< b'''
     def __init__(self,var_lst:list,sense:str,b:float,description:str):
@@ -8,6 +8,9 @@ class Equation:
             sense (str): ">","=" or "<"
             b (float): right side of equation
         """        
+        for var in var_lst:
+            if len(var)==3 and (isinstance(var[0],LPStateVar_add) or isinstance(var[0],LPStateVar_Decision_add)):
+                raise ValueError(f'The variable {var[0].name} is not time dependent and should not be called with a time stemp')
         self.var_lst = var_lst
         self.sense = sense
         self.b = b
